@@ -20,9 +20,10 @@ package MongoDB::BSON::Binary;
 # ABSTRACT: Binary type
 
 use version;
-our $VERSION = 'v0.708.4.0'; # from MongoDB-v0.708.4.0.tar.gz
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 #pod =head1 NAME
@@ -96,7 +97,7 @@ use constant {
 
 has data => (
     is => 'ro',
-    isa => 'Str',
+    isa => Str,
     required => 1
 );
 
@@ -108,7 +109,7 @@ has data => (
 
 has subtype => (
     is => 'ro',
-    isa => 'Int',
+    isa => Int,
     required => 0,
     default => MongoDB::BSON::Binary->SUBTYPE_GENERIC
 );
@@ -155,7 +156,7 @@ MongoDB::BSON::Binary - Binary type
 
 =head1 VERSION
 
-version v0.708.4.0
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
@@ -250,11 +251,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@friedo.com>
+Mike Friedman <friedo@mongodb.com>
 
 =item *
 
-Kristina Chodorow <k.chodorow@gmail.com>
+Kristina Chodorow <kristina@mongodb.com>
 
 =item *
 
