@@ -2,20 +2,22 @@ package MongoDB::BSON::Regexp;
 # ABSTRACT: Regular expression type
 
 use version;
-our $VERSION = 'v0.708.4.0'; # from MongoDB-v0.708.4.0.tar.gz
+our $VERSION = 'v0.999.998.5';
 
 use Moose;
+use MongoDB::Error;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 has pattern => ( 
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has flags => ( 
     is        => 'ro',
-    isa       => 'Str',
+    isa       => Str,
     required  => 0,
     predicate => 'has_flags',
     writer    => '_set_flags',
@@ -37,7 +39,8 @@ sub BUILD {
         my %seen;
         my @flags = grep { !$seen{$_}++ } split '', $self->flags;
         foreach my $f( @flags ) { 
-            die "Regexp flag $f is not supported by MongoDB" if not exists $ALLOWED_FLAGS{$f};
+            MongoDB::UsageError->throw("Regexp flag $f is not supported by MongoDB")
+              if not exists $ALLOWED_FLAGS{$f};
         }
 
         $self->_set_flags( join '', sort @flags );
@@ -60,7 +63,7 @@ MongoDB::BSON::Regexp - Regular expression type
 
 =head1 VERSION
 
-version v0.708.4.0
+version v0.999.998.5
 
 =head1 AUTHORS
 
@@ -72,11 +75,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@friedo.com>
+Mike Friedman <friedo@mongodb.com>
 
 =item *
 
-Kristina Chodorow <k.chodorow@gmail.com>
+Kristina Chodorow <kristina@mongodb.com>
 
 =item *
 
