@@ -20,7 +20,7 @@ package MongoDB::Code;
 # ABSTRACT: JavaScript Code
 
 use version;
-our $VERSION = 'v0.708.4.0'; # from MongoDB-v0.708.4.0.tar.gz
+our $VERSION = 'v0.999.998.5';
 
 #pod =head1 NAME
 #pod
@@ -29,6 +29,7 @@ our $VERSION = 'v0.708.4.0'; # from MongoDB-v0.708.4.0.tar.gz
 #pod =cut
 
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
 #pod =head1 ATTRIBUTES
@@ -41,7 +42,7 @@ use namespace::clean -except => 'meta';
 
 has code => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
@@ -53,7 +54,7 @@ has code => (
 
 has scope => (
     is       => 'ro',
-    isa      => 'HashRef',
+    isa      => HashRef,
     required => 0,
 );
 
@@ -73,7 +74,7 @@ MongoDB::Code - JavaScript Code
 
 =head1 VERSION
 
-version v0.708.4.0
+version v0.999.998.5
 
 =head1 NAME
 
@@ -99,11 +100,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@friedo.com>
+Mike Friedman <friedo@mongodb.com>
 
 =item *
 
-Kristina Chodorow <k.chodorow@gmail.com>
+Kristina Chodorow <kristina@mongodb.com>
 
 =item *
 
