@@ -20,48 +20,38 @@ package MongoDB::GridFS::File;
 # ABSTRACT: A Mongo GridFS file
 
 use version;
-our $VERSION = 'v0.708.4.0'; # from MongoDB-v0.708.4.0.tar.gz
+our $VERSION = 'v0.999.998.5';
 
-use MongoDB::GridFS;
+use MongoDB::Error;
 use IO::File;
 use Moose;
+use Types::Standard -types;
 use namespace::clean -except => 'meta';
 
-#pod =head1 SYNOPSIS
-#pod
-#pod     use MongoDB::GridFS::File;
-#pod
-#pod     my $outfile = IO::File->new("outfile", "w");
-#pod     my $file = $grid->find_one;
-#pod     $file->print($outfile);
-#pod
-#pod =cut
-
 has _grid => (
     is       => 'ro',
-    isa      => 'MongoDB::GridFS',
+    isa      => InstanceOf['MongoDB::GridFS'],
     required => 1,
 );
 
-#pod =head1 ATTRIBUTES
+#pod =attr info
 #pod
-#pod =head2 info
-#pod
-#pod A hash of info information saved with this file.
+#pod A hash reference of metadata saved with this file.
 #pod
 #pod =cut
 
 has info => (
     is => 'ro',
-    isa => 'HashRef',
+    isa => HashRef,
     required => 1,
 );
 
-#pod =head1 METHODS
+
+#pod =method print
 #pod
-#pod =head2 print ($fh, $length?, $offset?)
-#pod
-#pod     $written = $file->print($fh, 50, 200);
+#pod     $written = $file->print($fh);
+#pod     $written = $file->print($fh, $length);
+#pod     $written = $file->print($fh, $length, $offset)
 #pod
 #pod Writes the number of bytes specified from the offset specified 
 #pod to the given file handle.  If no C<$length> or C<$offset> are
@@ -81,8 +71,8 @@ sub print {
 
     my $cursor = $self->_grid->chunks->query({"files_id" => $self->info->{"_id"}})->sort({"n" => 1});
 
-    if ( $self->info->{length} && !$cursor->has_next ) {
-        MongoDB::Error->throw(
+    if ( !$cursor->has_next ) {
+        MongoDB::GridFSError->throw(
             sprintf( "GridFS file corrupt: no chunks found for file ID '%s'",
                 $self->info->{_id} )
         );
@@ -127,18 +117,17 @@ sub print {
     return $written;
 }
 
-#pod =head2 slurp ($length?, $offset?)
+#pod =method slurp
 #pod
-#pod     $bytes = $file->slurp(50, 200);
 #pod     $all   = $file->slurp
+#pod     $bytes = $file->slurp($length);
+#pod     $bytes = $file->slurp($length, $offset);
 #pod
-#pod Return the number of bytes specified from the offset specified
-#pod to the given file handle.  If no C<$length> or C<$offset> are
-#pod given, the entire file is return.
+#pod Return the number of bytes specified from the offset specified.  If no
+#pod C<$length> or C<$offset> are given, the entire file is returned.
 #pod
 #pod =cut
 
-
 sub slurp {
     my ($self,$length,$offset) = @_;
     my $bytes = '';
@@ -171,41 +160,70 @@ MongoDB::GridFS::File - A Mongo GridFS file
 
 =head1 VERSION
 
-version v0.708.4.0
+version v0.999.998.5
 
 =head1 SYNOPSIS
 
     use MongoDB::GridFS::File;
 
-    my $outfile = IO::File->new("outfile", "w");
-    my $file = $grid->find_one;
+    $outfile = IO::File->new("outfile", "w");
+    $file = $grid->find_one;
     $file->print($outfile);
 
+=head1 USAGE
+
+=head2 Error handling
+
+Unless otherwise explictly documented, all methods throw exceptions if
+an error occurs.  The error types are documented in L<MongoDB::Error>.
+
+To catch and handle errors, the L<Try::Tiny> and L<Safe::Isa> modules
+are recommended:
+
+    use Try::Tiny;
+    use Safe::Isa; # provides $_isa
+
+    $bytes = try {
+        $file->slurp;
+    }
+    catch {
+        if ( $_->$_isa("MongoDB::TimeoutError" ) {
+            ...
+        }
+        else {
+            ...
+        }
+    };
+
+To retry failures automatically, consider using L<Try::Tiny::Retry>.
+
 =head1 ATTRIBUTES
 
 =head2 info
 
-A hash of info information saved with this file.
+A hash reference of metadata saved with this file.
 
 =head1 METHODS
 
-=head2 print ($fh, $length?, $offset?)
+=head2 print
 
-    $written = $file->print($fh, 50, 200);
+    $written = $file->print($fh);
+    $written = $file->print($fh, $length);
+    $written = $file->print($fh, $length, $offset)
 
 Writes the number of bytes specified from the offset specified 
 to the given file handle.  If no C<$length> or C<$offset> are
 given, the entire file is written to C<$fh>.  Returns the number
 of bytes written.
 
-=head2 slurp ($length?, $offset?)
+=head2 slurp
 
-    $bytes = $file->slurp(50, 200);
     $all   = $file->slurp
+    $bytes = $file->slurp($length);
+    $bytes = $file->slurp($length, $offset);
 
-Return the number of bytes specified from the offset specified
-to the given file handle.  If no C<$length> or C<$offset> are
-given, the entire file is return.
+Return the number of bytes specified from the offset specified.  If no
+C<$length> or C<$offset> are given, the entire file is returned.
 
 =head1 AUTHORS
 
@@ -217,11 +235,11 @@ David Golden <david@mongodb.com>
 
 =item *
 
-Mike Friedman <friedo@friedo.com>
+Mike Friedman <friedo@mongodb.com>
 
 =item *
 
-Kristina Chodorow <k.chodorow@gmail.com>
+Kristina Chodorow <kristina@mongodb.com>
 
 =item *
 
