@@ -24,22 +24,33 @@ use warnings;
 use Exporter 'import';
 use MongoDB;
 use Test::More;
+use boolean;
 use version;
 
 our @EXPORT_OK = qw(
-  build_client get_test_db server_version server_type clear_testdbs
+  build_client get_test_db server_version server_type clear_testdbs get_capped
 );
 
 my @testdbs;
 
 # abstract building a connection
 sub build_client {
-    my @args = @_;
-    my $host = exists $ENV{MONGOD} ? $ENV{MONGOD} : 'localhost';
+    my %args = @_;
+    my $host =
+        exists $args{host}  ? delete $args{host}
+      : exists $ENV{MONGOD} ? $ENV{MONGOD}
+      :                       'localhost';
 
     # long query timeout may help spurious failures on heavily loaded CI machines
-    return MongoDB::MongoClient->new(
-        host => $host, ssl => $ENV{MONGO_SSL}, find_master => 1, query_timeout => 60000, @args,
+    return MongoDB->connect(
+        $host,
+        {
+            ssl                         => $ENV{MONGO_SSL},
+            find_master                 => 1,
+            query_timeout               => 60000,
+            server_selection_timeout_ms => 1000,
+            %args,
+        }
     );
 }
 
@@ -52,18 +63,29 @@ sub get_test_db {
     return  $db;
 }
 
+sub get_capped {
+    my ($db, $name, %args) = @_;
+    $name ||= 'capped' . int(rand(2**31));
+    $args{size} ||= 500_000;
+    $db->run_command([ create => $name, capped => true, %args ]);
+    return $db->get_collection($name);
+}
 
+# XXX eventually, should move away from this and towards a fixture object instead
 BEGIN {
     eval {
-        my $conn = build_client();
-        my $testdb = get_test_db($conn);
-        eval { $conn->get_database("admin")->_try_run_command({ serverStatus => 1 }) }
+        my $conn = build_client( server_selection_timeout_ms => 1000 );
+        $conn->_topology->scan_all_servers;
+        $conn->_topology->_dump;
+        eval { $conn->_topology->get_writable_link }
+            or die "couldn't connect";
+        $conn->get_database("admin")->run_command({ serverStatus => 1 })
             or die "Database has auth enabled\n";
     };
 
     if ( $@ ) {
         (my $err = $@) =~ s/\n//g;
-        if ( $err =~ /couldn't connect/ ) {
+        if ( $err =~ /couldn't connect|connection refused/i ) {
             $err = "no mongod on " . ($ENV{MONGOD} || "localhost:27017");
             $err .= ' and $ENV{MONGOD} not set' unless $ENV{MONGOD};
         }
@@ -85,7 +107,7 @@ sub server_type {
     my $server_type;
 
     # check database type
-    my $ismaster = $conn->get_database('admin')->_try_run_command({ismaster => 1});
+    my $ismaster = $conn->get_database('admin')->run_command({ismaster => 1});
     if (exists $ismaster->{msg} && $ismaster->{msg} eq 'isdbgrid') {
         $server_type = 'Mongos';
     }
